@@ -62,7 +62,7 @@ lexicon = [("float", r"[-+]?(?:(?:[0-9]*\.[0-9]+)|(?:[0-9]+\.?))(?:[Ee][-+]?[0-9
 
 
 class Lexer(object):
-    """ Break SVG path data into tokens.
+    """Break SVG path data into tokens.
 
     The SVG spec requires that tokens are greedy. This lexer relies on Python's
     regexes defaulting to greediness.
@@ -81,7 +81,7 @@ class Lexer(object):
         self.regex = re.compile(self.regex_string)
 
     def lex(self, text):
-        """ Yield (token_type, str_data) tokens.
+        """Yield (token_type, str_data) tokens.
 
         The last token will be (EOF, None) where EOF is the singleton object
         defined in this module.
@@ -99,7 +99,7 @@ svg_lexer = Lexer(lexicon)
 
 
 class SVGPathParser(object):
-    """ Parse SVG <path> data into a list of commands.
+    """Parse SVG <path> data into a list of commands.
 
     Each distinct command will take the form of a tuple (command, data). The
     `command` is just the character string that starts the command group in the
@@ -126,8 +126,7 @@ class SVGPathParser(object):
         self.number_tokens = list(["int", "float"])
 
     def parse(self, text):
-        """ Parse a string of SVG <path> data.
-        """
+        """Parse a string of SVG <path> data."""
         gen = self.lexer.lex(text)
         next_val_fn = partial(next, *(gen,))
         token = next_val_fn()
